@@ -3,20 +3,9 @@
 
 # Copyright (C) 2008-2016 Martin Sandve Alnæs
 #
-# This file is part of UFL.
+# This file is part of UFL (https://www.fenicsproject.org)
 #
-# UFL is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Lesser General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# UFL is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public License
-# along with UFL. If not, see <http://www.gnu.org/licenses/>.
+# SPDX-License-Identifier:    LGPL-3.0-or-later
 
 
 from ufl.log import error, warning
@@ -116,6 +105,9 @@ class GenericDerivativeRuleset(MultiFunction):
     # Literals are by definition independent of any differentiation variable
     constant_value = independent_terminal
 
+    # Constants are independent of any differentiation
+    constant = independent_terminal
+
     # Rules for form arguments must be specified in specialized rule set
     form_argument = override
 
@@ -297,8 +289,11 @@ class GenericDerivativeRuleset(MultiFunction):
 
     def abs(self, o, df):
         f, = o.ufl_operands
-        # return conditional(eq(f, 0), 0, Product(sign(f), df))
-        return sign(f) * df
+        # return conditional(eq(f, 0), 0, Product(sign(f), df)) abs is
+        # not complex differentiable, so we workaround the case of a
+        # real F in complex mode by defensively casting to real inside
+        # the sign.
+        return sign(Real(f)) * df
 
     # --- Complex algebra
 
@@ -547,6 +542,10 @@ class GradRuleset(GenericDerivativeRuleset):
     def reference_value(self, o):
         # grad(o) == grad(rv(f)) -> K_ji*rgrad(rv(f))_rj
         f = o.ufl_operands[0]
+        if f.ufl_element().mapping() == "physical":
+            # TODO: Do we need to be more careful for immersed things?
+            return ReferenceGrad(o)
+
         if not f._ufl_is_terminal_:
             error("ReferenceValue can only wrap a terminal")
         domain = f.ufl_domain()
@@ -559,6 +558,7 @@ class GradRuleset(GenericDerivativeRuleset):
     def reference_grad(self, o):
         # grad(o) == grad(rgrad(rv(f))) -> K_ji*rgrad(rgrad(rv(f)))_rj
         f = o.ufl_operands[0]
+
         valid_operand = f._ufl_is_in_reference_frame_ or isinstance(f, (JacobianInverse, SpatialCoordinate))
         if not valid_operand:
             error("ReferenceGrad can only wrap a reference frame type!")
