@@ -3,20 +3,9 @@
 
 # Copyright (C) 2008-2016 Martin Sandve Alnæs
 #
-# This file is part of UFL.
+# This file is part of UFL (https://www.fenicsproject.org)
 #
-# UFL is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Lesser General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# UFL is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public License
-# along with UFL. If not, see <http://www.gnu.org/licenses/>.
+# SPDX-License-Identifier:    LGPL-3.0-or-later
 
 
 from ufl.log import error
@@ -88,10 +77,6 @@ class RestrictionPropagator(MultiFunction):
     # want something else for facet functions in future.
     grad = _require_restriction
 
-    # Assuming averages are also applied directly to the terminal or grad nodes
-    cell_avg = _require_restriction
-    facet_avg = _ignore_restriction
-
     def variable(self, o, op, label):
         "Strip variable."
         return op
@@ -117,6 +102,7 @@ class RestrictionPropagator(MultiFunction):
 
     # Default: Literals should ignore restriction
     constant_value = _ignore_restriction
+    constant = _ignore_restriction
 
     # Even arguments with continuous elements such as Lagrange must be
     # restricted to associate with the right part of the element
