@@ -3,20 +3,9 @@
 
 # Copyright (C) 2008-2016 Martin Sandve Alnæs and Anders Logg
 #
-# This file is part of UFL.
+# This file is part of UFL (https://www.fenicsproject.org)
 #
-# UFL is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Lesser General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# UFL is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public License
-# along with UFL. If not, see <http://www.gnu.org/licenses/>.
+# SPDX-License-Identifier:    LGPL-3.0-or-later
 #
 # Modified by Anders Logg, 2009-2010
 
@@ -30,28 +19,23 @@ from ufl.algorithms.analysis import has_exact_type
 
 class Replacer(MultiFunction):
     def __init__(self, mapping):
-        MultiFunction.__init__(self)
-        self._mapping = mapping
-        if not all(k._ufl_is_terminal_ for k in mapping.keys()):
-            error("This implementation can only replace Terminal objects.")
+        super().__init__()
+        self.mapping = mapping
         if not all(k.ufl_shape == v.ufl_shape for k, v in mapping.items()):
             error("Replacement expressions must have the same shape as what they replace.")
 
-    expr = MultiFunction.reuse_if_untouched
-
-    def terminal(self, o):
-        e = self._mapping.get(o)
-        if e is None:
-            return o
-        else:
-            return e
+    def expr(self, o, *args):
+        try:
+            return self.mapping[o]
+        except KeyError:
+            return self.reuse_if_untouched(o, *args)
 
     def coefficient_derivative(self, o):
         error("Derivatives should be applied before executing replace.")
 
 
 def replace(e, mapping):
-    """Replace terminal objects in expression.
+    """Replace subexpressions in expression.
 
     @param e:
         An Expr or Form.
@@ -61,6 +45,14 @@ def replace(e, mapping):
     mapping2 = dict((k, as_ufl(v)) for (k, v) in mapping.items())
 
     # Workaround for problem with delayed derivative evaluation
+    # The problem is that J = derivative(f(g, h), g) does not evaluate immediately
+    # So if we subsequently do replace(J, {g: h}) we end up with an expression:
+    # derivative(f(h, h), h)
+    # rather than what were were probably thinking of:
+    # replace(derivative(f(g, h), g), {g: h})
+    #
+    # To fix this would require one to expand derivatives early (which
+    # is not attractive), or make replace lazy too.
     if has_exact_type(e, CoefficientDerivative):
         # Hack to avoid circular dependencies
         from ufl.algorithms.ad import expand_derivatives
