@@ -3,20 +3,9 @@
 
 # Copyright (C) 2008-2016 Martin Sandve Alnæs
 #
-# This file is part of UFL.
+# This file is part of UFL (https://www.fenicsproject.org)
 #
-# UFL is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Lesser General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# UFL is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public License
-# along with UFL. If not, see <http://www.gnu.org/licenses/>.
+# SPDX-License-Identifier:    LGPL-3.0-or-later
 #
 # Modified by Anders Logg, 2009.
 # Modified by Kristian B. Oelgaard, 2009
@@ -27,14 +16,12 @@
 import numbers
 import functools
 
-from ufl.utils.str import as_native_str
-from ufl.utils.str import as_native_strings
 from ufl.log import error
 from ufl.core.ufl_type import attach_operators_from_hash_data
 
 
 # Export list for ufl.classes
-__all_classes__ = as_native_strings(["AbstractCell", "Cell", "TensorProductCell"])
+__all_classes__ = ["AbstractCell", "Cell", "TensorProductCell"]
 
 
 # --- The most abstract cell class, base class for other cell types
@@ -44,8 +31,8 @@ class AbstractCell(object):
     dimensions known.
 
     """
-    __slots__ = as_native_strings(("_topological_dimension",
-                                   "_geometric_dimension"))
+    __slots__ = ("_topological_dimension",
+                 "_geometric_dimension")
 
     def __init__(self, topological_dimension, geometric_dimension):
         # Validate dimensions
@@ -118,7 +105,7 @@ cellname2facetname = {"interval": "vertex",
 @attach_operators_from_hash_data
 class Cell(AbstractCell):
     "Representation of a named finite element cell with known structure."
-    __slots__ = as_native_strings(("_cellname",))
+    __slots__ = ("_cellname",)
 
     def __init__(self, cellname, geometric_dimension=None):
         "Initialize basic cell description."
@@ -202,7 +189,7 @@ class Cell(AbstractCell):
             r = name
         else:
             r = "Cell(%s, %s)" % (repr(name), repr(gdim))
-        return as_native_str(r)
+        return r
 
     def _ufl_hash_data_(self):
         return (self._geometric_dimension, self._topological_dimension,
@@ -211,7 +198,7 @@ class Cell(AbstractCell):
 
 @attach_operators_from_hash_data
 class TensorProductCell(AbstractCell):
-    __slots__ = as_native_strings(("_cells",))
+    __slots__ = ("_cells",)
 
     def __init__(self, *cells, **kwargs):
         keywords = list(kwargs.keys())
