@@ -3,27 +3,14 @@
 
 # Copyright (C) 2012-2016 Anders Logg and Martin Sandve Alnæs
 #
-# This file is part of UFL.
+# This file is part of UFL (https://www.fenicsproject.org)
 #
-# UFL is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Lesser General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# UFL is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public License
-# along with UFL. If not, see <http://www.gnu.org/licenses/>.
+# SPDX-License-Identifier:    LGPL-3.0-or-later
 
 from ufl.log import error
-from ufl.utils.str import as_native_str
-from ufl.utils.str import as_native_strings
 
 # Export list for ufl.classes
-__all_classes__ = as_native_strings(["Equation"])
+__all_classes__ = ["Equation"]
 
 
 class Equation(object):
@@ -68,4 +55,4 @@ class Equation(object):
 
     def __repr__(self):
         r = "Equation(%s, %s)" % (repr(self.lhs), repr(self.rhs))
-        return as_native_str(r)
+        return r
